@@ -9,6 +9,7 @@ from django.db.models.manager import Manager
 from django.db.models.signals import class_prepared
 from django.utils.translation import get_language
 from hvad.descriptors import LanguageCodeAttribute, TranslatedAttribute
+from hvad.exceptions import WrongManager
 from hvad.fields import SingleTranslationObject, MasterKey
 from hvad.manager import TranslationManager
 from hvad.settings import hvad_settings
@@ -176,11 +177,11 @@ class TranslatedFields:
 class BaseTranslationModel(models.Model):
     """ Base model for all translation models """
 
-    def _get_unique_checks(self, exclude=None):
+    def _get_unique_checks(self, exclude=None, *args, **kwargs):
         # Due to the way translations are handled, checking for unicity of
         # the ('language_code', 'master') constraint is useless. We filter it out
         # here so as to avoid a useless query
-        unique_checks, date_checks = super()._get_unique_checks(exclude=exclude)
+        unique_checks, date_checks = super()._get_unique_checks(exclude=exclude,  *args, **kwargs)
         unique_checks = [check for check in unique_checks
                          if check != (self.__class__, ('language_code', 'master'))]
         return unique_checks, date_checks
@@ -201,6 +202,13 @@ class TranslatableModel(models.Model):
         abstract = True
         base_manager_name = '_plain_manager'
 
+    def serializable_value(self, field_name):
+        try:
+            field = self._meta.get_field(field_name)
+        except (FieldDoesNotExist, WrongManager):
+            return getattr(self, field_name)
+        return getattr(self, field.attname)
+
     def __init__(self, *args, **kwargs):
         # Split arguments into shared/translatd
         veto_names = ('pk', 'master', 'master_id', self._meta.translations_model._meta.pk.name)
@@ -287,7 +295,7 @@ class TranslatableModel(models.Model):
         super().clean_fields(exclude=exclude)
         translation = get_cached_translation(self)
         if translation is not None:
-            translation.clean_fields(exclude=exclude + ['id', 'master', 'master_id', 'language_code'])
+            translation.clean_fields(exclude=type(exclude)([*exclude, 'id', 'master', 'master_id', 'language_code']))
 
     def validate_unique(self, exclude=None):
         super().validate_unique(exclude=exclude)
